summaryrefslogtreecommitdiff
path: root/mcon
diff options
context:
space:
mode:
Diffstat (limited to 'mcon')
-rw-r--r--mcon/U/Head.U2
-rw-r--r--mcon/U/Oldsym.U2
-rw-r--r--mcon/U/Options.U2
-rw-r--r--mcon/U/patchlevel.U28
-rwxr-xr-xmcon/man/mconfig.SH6
-rwxr-xr-xmcon/mconfig.SH3
-rwxr-xr-xmcon/mlint.SH3
-rwxr-xr-xmcon/mxref.SH3
-rw-r--r--mcon/pl/configure.pl4
-rw-r--r--mcon/pl/lint.pl1
10 files changed, 43 insertions, 11 deletions
diff --git a/mcon/U/Head.U b/mcon/U/Head.U
index bb1464b..7667c8a 100644
--- a/mcon/U/Head.U
+++ b/mcon/U/Head.U
@@ -88,7 +88,7 @@
# $Id$
#
-# Generated on <DATE> [metaconfig <VERSION> PL<PATCHLEVEL>]
+# Generated on <DATE> [metaconfig <VERSION>-<REVISION>]
cat >c1$$ <<EOF
ARGGGHHHH!!!!!
diff --git a/mcon/U/Oldsym.U b/mcon/U/Oldsym.U
index 8b11133..816a6f9 100644
--- a/mcon/U/Oldsym.U
+++ b/mcon/U/Oldsym.U
@@ -28,6 +28,8 @@
: add special variables
$test -f $src/patchlevel.h && \
awk '/^#define/ {printf "%s=%s\n",$2,$3}' $src/patchlevel.h >>config.sh
+$test -f $src/revision.h && \
+awk '/^#define/ {printf "%s=%s\n",$2,$3}' $src/revision.h >>config.sh
echo "CONFIG=true" >>config.sh
: propagate old symbols
diff --git a/mcon/U/Options.U b/mcon/U/Options.U
index a38f565..0508d27 100644
--- a/mcon/U/Options.U
+++ b/mcon/U/Options.U
@@ -275,7 +275,7 @@ while test $# -gt 0; do
esac
shift
;;
- -V) echo "$me generated by metaconfig <VERSION> PL<PATCHLEVEL>." >&2
+ -V) echo "$me generated by metaconfig <VERSION>-<REVISION>." >&2
exit 0;;
--) break;;
-*) echo "$me: unknown option $1" >&2; shift; error=true;;
diff --git a/mcon/U/patchlevel.U b/mcon/U/patchlevel.U
index 459f87f..18a3f98 100644
--- a/mcon/U/patchlevel.U
+++ b/mcon/U/patchlevel.U
@@ -15,15 +15,20 @@
?RCS: Revision 3.0 1993/08/18 12:09:31 ram
?RCS: Baseline for dist 3.0 netwide release.
?RCS:
-?MAKE:patchlevel: package baserev test rsrc
+?MAKE:patchlevel revision: package baserev test rsrc
?MAKE: -pick add $@ %<
?S:patchlevel:
?S: The patchlevel level of this package.
?S: The value of patchlevel comes from the patchlevel.h file.
?S:.
-: get the patchlevel
+?S:revision:
+?S: The revision / build of this package.
+?S: The value is derived from the REVISION define in the revision.h file.
+?S: When revision is defined, the patch level should be ignored if 0.
+?S:.
+: get the patchlevel / revision
echo " "
-echo "Getting the current patchlevel..." >&4
+echo "Getting the current patchlevel / revision..." >&4
if $test -r $rsrc/patchlevel.h;then
patchlevel=`awk \
'/^#[ ]*define[ ][ ]*PATCHLEVEL/ {print $3}' \
@@ -31,5 +36,20 @@ if $test -r $rsrc/patchlevel.h;then
else
patchlevel=0
fi
-echo "(You have $package $baserev PL$patchlevel.)"
+if $test -r $rsrc/revision.h;then
+ revision=`awk \
+ '/^#[ ]*define[ ][ ]*REVISION/ {print $3}' \
+ < $rsrc/revision.h`
+else
+ revision=0
+fi
+case "$revision" in
+0) echo "(You have $package $baserev PL$patchlevel.)" ;;
+*)
+ case "$patchlevel" in
+ 0) echo "(You have $package $baserev-$revision)";;
+ *) echo "(You have $package $baserev-$revision PL$patchlevel)";;
+ esac
+ ;;
+esac
diff --git a/mcon/man/mconfig.SH b/mcon/man/mconfig.SH
index 44a6ae5..1275b75 100755
--- a/mcon/man/mconfig.SH
+++ b/mcon/man/mconfig.SH
@@ -1455,7 +1455,11 @@ your \fI.package\fR.
The name of the package, as derived from your \fI.package\fR file.
.TP
<PATCHLEVEL>
-The patch level of the \fImetaconfig\fR program.
+The patch level of the \fImetaconfig\fR program (deprecated in favor
+of <REVISION>).
+.TP
+<REVISION>
+The SVN revision level of the \fImetaconfig\fR program.
.TP
<VERSION>
The version number of the \fImetaconfig\fR program.
diff --git a/mcon/mconfig.SH b/mcon/mconfig.SH
index adcf0a2..94ade5f 100755
--- a/mcon/mconfig.SH
+++ b/mcon/mconfig.SH
@@ -58,6 +58,7 @@ $startperl
\$MC = '$privlib';
\$version = '$VERSION';
\$patchlevel = '$PATCHLEVEL';
+\$revision = '$REVISION';
\$grep = '$grep';
!GROK!THIS!
@@ -78,7 +79,7 @@ chdir $WD || die "Can't chdir back to $WD: $!\n";
++$opt_M if -f 'confmagic.h'; # Force -M if confmagic.h already there
if ($opt_V) {
- print STDERR "metaconfig $version PL$patchlevel\n";
+ print STDERR "metaconfig $version-$revision\n";
exit 0;
} elsif ($opt_h) {
&usage;
diff --git a/mcon/mlint.SH b/mcon/mlint.SH
index 62d4021..9e0cbf6 100755
--- a/mcon/mlint.SH
+++ b/mcon/mlint.SH
@@ -51,6 +51,7 @@ $startperl
\$MC = '$privlib';
\$version = '$VERSION';
\$patchlevel = '$PATCHLEVEL';
+\$revision = '$REVISION';
\$grep = '$grep';
!GROK!THIS!
@@ -60,7 +61,7 @@ require 'getopts.pl';
&usage unless &Getopts("hklVL:");
if ($opt_V) {
- print STDERR "metalint $version PL$patchlevel\n";
+ print STDERR "metalint $version-$revision\n";
exit 0;
} elsif ($opt_h) {
&usage;
diff --git a/mcon/mxref.SH b/mcon/mxref.SH
index 51ea87f..b6d8dcb 100755
--- a/mcon/mxref.SH
+++ b/mcon/mxref.SH
@@ -51,6 +51,7 @@ $startperl
\$MC = '$privlib';
\$version = '$VERSION';
\$patchlevel = '$PATCHLEVEL';
+\$revision = '$REVISION';
\$grep = '$grep';
!GROK!THIS!
@@ -68,7 +69,7 @@ chop($MC = `pwd`); # Real metaxref lib path (no symbolic links)
chdir $WD || die "Can't chdir back to $WD: $!\n";
if ($opt_V) {
- print STDERR "metaxref $version PL$patchlevel\n";
+ print STDERR "metaxref $version-$revision\n";
exit 0;
} elsif ($opt_h) {
&usage;
diff --git a/mcon/pl/lint.pl b/mcon/pl/lint.pl
index ba5c407..c790011 100644
--- a/mcon/pl/lint.pl
+++ b/mcon/pl/lint.pl
@@ -115,6 +115,7 @@ sub init_extraction {
MAINTLOC
VERSION
PATCHLEVEL
+ REVISION
DATE
BASEREV
);
diff --git a/mcon/pl/configure.pl b/mcon/pl/configure.pl
index f78925f..a5aed29 100644
--- a/mcon/pl/configure.pl
+++ b/mcon/pl/configure.pl
@@ -110,7 +110,9 @@ sub process_command {
s/<PACKAGENAME>/$package/g;
s/<MAINTLOC>/$maintloc/g;
s/<VERSION>/$version/g; # This is metaconfig's version
- s/<PATCHLEVEL>/$patchlevel/g; # And patchlevel information
+ s/<REVISION>/$revision/g; # And revision information
+ warn "\"$file\": usage of <PATCHLEVEL> is deprecated\n"
+ if s/<PATCHLEVEL>/$patchlevel/g;
s/<DATE>/$date/g;
s/<BASEREV>/$baserev/g;
s/<\$(\w+)>/eval("\$$1")/ge; # <$var> -> $var substitution